@@ -8,7 +8,7 @@ class READMESpider(scrapy.Spider):
             self,
             pipe,
             url
-         ):
+    ):
         super().__init__(READMESpider.name)
 
         self.pipe = pipe
@@ -32,8 +32,6 @@ class READMESpider(scrapy.Spider):
         }
 
     def close(self, spider, reason):
-        self.pipe["failed"] = not bool(self.pipe["result"])
+        self.pipe["failed"] = not bool(self.pipe.get("result", ""))
 
         super().close(spider, reason)
-
-
